# Internal documentation -------------------------------------------------------
#
# Log-transformation

logEst <- function(y) {
  y <- log(y)
  return(y)
}
